@@ -100,7 +100,7 @@ __DATA__
                             </a>
                         </li>
                         <li class="nav-item">
-                            <a class="nav-link" href="https://kiwiirc.com/nextclient/#irc://irc.perl.org/#yancy?nick=www-guest-?">
+                            <a class="nav-link" href="https://kiwiirc.com/nextclient/#irc://irc.freenode.org/#mojo-yancy?nick=www-guest-?">
                                 Chat
                             </a>
                         </li>
