@@ -59,7 +59,7 @@ Vue.component( 'foreign-key-field', {
     data: function () {
         // XXX Replace with VueX
         var schema = Yancy.schema[ this.schemaName ].operations.set.schema;
-        return {
+        var data = {
             _value: this.$props.value,
             displayValue: 'Loading...',
             loading: true,
@@ -67,11 +67,24 @@ Vue.component( 'foreign-key-field', {
             searchQuery: '',
             searchResults: [
             ],
-            displayField: this.$props.displayField || (
-                schema['x-list-columns'] ? schema['x-list-columns'][0] : ( schema['x-id-field'] || 'id' )
-            ),
+            displayField: this.$props.displayField,
             valueField: this.$props.valueField || schema['x-id-field'] || 'id'
         };
+
+        if ( !data.displayField ) {
+            var schemaCols = schema['x-list-columns'];
+            if ( schemaCols && typeof schemaCols[0] == 'object' ) {
+                data.displayTemplate = schemaCols[0].template;
+            }
+            else if ( schemaCols ) {
+                data.displayField = schemaCols[0];
+            }
+            else {
+                data.displayField = schema['x-id-field'] || 'id';
+            }
+        }
+
+        return data;
     },
     mounted: function () {
         var dropdownToggleEl = $( '#' + this.uid + ' .dropdown-toggle' );
@@ -106,8 +119,13 @@ Vue.component( 'foreign-key-field', {
             })
             .then( this.updateDisplayValue );
         },
+        displayItem: function ( item ) {
+            return this.$data.displayTemplate
+                ? Yancy.fillTemplate( this.$data.displayTemplate, item )
+                : item[ this.$data.displayField ];
+        },
         updateDisplayValue: function ( item ) {
-            this.displayValue = item[ this.$data.displayField ];
+            this.displayValue = this.displayItem( item );
             this.loading = false;
         },
         showDropdown: function () {
@@ -115,10 +133,20 @@ Vue.component( 'foreign-key-field', {
             dropdownEl.find( '.dropdown-toggle' ).dropdown('toggle');
         },
         submitSearch: function () {
+            var query = this.searchQuery,
+                url = specUrl + '/' + this.$props.schemaName + '?$match=any';
+            if ( this.$data.displayTemplate ) {
+                var match = this.$data.displayTemplate.match( /\{[^}]+\}/g );
+                match.forEach( function (field) {
+                    url += '&' + field.replace(/[{}]/g, '') + '=' + encodeURIComponent( query );
+                } );
+            }
+            else {
+                url += '&' + this.$data.displayField + '=' + encodeURIComponent( query );
+            }
             $.ajax({
                 method: 'GET',
-                url: specUrl + '/' + this.$props.schemaName +
-                    '?' + this.$data.displayField + '=' + encodeURIComponent( this.searchQuery ),
+                url: url,
                 context: this
             })
             .then( this.updateSearchResults );
@@ -127,7 +155,7 @@ Vue.component( 'foreign-key-field', {
             var results = [];
             for ( var i = 0; i < data.items.length; i++ ) {
                 results.push({
-                    display: data.items[i][ this.$data.displayField ],
+                    display: this.displayItem( data.items[i] ),
                     value: data.items[i][ this.$data.valueField ]
                 });
             }
@@ -139,7 +167,7 @@ Vue.component( 'foreign-key-field', {
         select: function (item) {
             this.$data._value = item.value;
             this.$emit( 'input', item.value );
-            this.updateDisplayValue( item );
+            this.displayValue = item.display;
             this.searchResults = [];
             this.searchQuery = '';
             $( '#' + this.uid ).find( '.dropdown-toggle' ).dropdown('hide');
@@ -718,7 +746,7 @@ var app = window.Yancy = new Vue({
         saveItem: function (i) {
             var self = this,
                 value = this.prepareSaveItem( this.items[i], this.currentOperations['set'].schema ),
-                url = this.fillUrl( this.currentOperations['set'].url, this.openedOldValue );
+                url = Yancy.fillTemplate( this.currentOperations['set'].url, this.openedOldValue );
             delete this.error.saveItem;
             this.$set( this, 'formError', {} );
             $.ajax(
@@ -856,7 +884,7 @@ var app = window.Yancy = new Vue({
                 self = this,
                 schema = this.currentSchema,
                 value = $( '#data-' + i ).val(),
-                url = this.fillUrl( this.currentOperations['delete'].url, this.items[i] );
+                url = Yancy.fillTemplate( this.currentOperations['delete'].url, this.items[i] );
             $.ajax(
                 {
                     url: url,
@@ -881,25 +909,6 @@ var app = window.Yancy = new Vue({
             window.scrollTo( 0, 0 );
         },
 
-        fillUrl: function ( tmpl, data ) {
-            return tmpl.replace( /\{([^}]+)\}/g, function ( match, field ) {
-                if ( !data[field].replace ) {
-                    // This must not be a string, so we can't escape it...
-                    return data[field];
-                }
-                // This works the same as Mojo::Util xml_escape
-                return data[field].replace( /[&<>"']/g, function ( match ) {
-                    switch ( match ) {
-                        case '&': return '&amp;';
-                        case '<': return '&lt;';
-                        case '>': return '&gt;';
-                        case '"': return '&quot;';
-                        case "'": return '&#039;';
-                    }
-                } );
-            } );
-        },
-
         renderValue: function ( field, value ) {
             var schema = this.currentSchema;
             if ( !schema.properties[ field ] ) {
@@ -921,7 +930,26 @@ var app = window.Yancy = new Vue({
         },
 
         rowViewUrl: function ( data ) {
-            return this.fillUrl( this.currentSchema[ 'x-view-item-url' ], data );
+            return Yancy.fillTemplate( this.currentSchema[ 'x-view-item-url' ], data );
+        },
+
+        fillTemplate: function ( tmpl, data ) {
+            return tmpl.replace( /\{([^}]+)\}/g, function ( match, field ) {
+                if ( !data[field].replace ) {
+                    // This must not be a string, so we can't escape it...
+                    return data[field];
+                }
+                // This works the same as Mojo::Util xml_escape
+                return data[field].replace( /[&<>"']/g, function ( match ) {
+                    switch ( match ) {
+                        case '&': return '&amp;';
+                        case '<': return '&lt;';
+                        case '>': return '&gt;';
+                        case '"': return '&quot;';
+                        case "'": return '&#039;';
+                    }
+                } );
+            } );
         },
 
         addToast: function ( toast ) {
